from typing import Optional

import os
import urllib.request
import logging

from matemat.db.primitives.Product import Product
from matemat.interfacing.stock import StockProvider
from matemat.webserver.config import get_config


class UncannyStockProvider(StockProvider):

    def __init__(self):
        super().__init__()
        self.logger = logging.getLogger('UncannyStockProvider')


    @classmethod
    def needs_update(cls) -> bool:
        return False

    def get_stock(self, product: Product) -> Optional[int]:
        if not product.stockable:
            return None
        c = get_config().get('interfaces', {})
        slot = c.get(f'productmap{product.id}')
        if not slot:
            # Item not mapped to a physical stock
            return None
        url = os.path.join(c.get('host', 'http://127.0.0.1:8000/'), 'level', str(slot))
        self.logger.info(url)
        try:
            request = urllib.request.urlopen(url)
        except BaseException as e:
            self.logger.error(str(e))
            return None
        return 42 if 'full' in request.read().decode() else 0

